import ec2 = require('@aws-cdk/aws-ec2');
import secretsmanager = require('@aws-cdk/aws-secretsmanager');
import cdk = require('@aws-cdk/cdk');
/**
 * A serverless application location.
 */
export declare class ServerlessApplicationLocation {
    static readonly MariaDbRotationSingleUser: ServerlessApplicationLocation;
    static readonly MysqlRotationSingleUser: ServerlessApplicationLocation;
    static readonly OracleRotationSingleUser: ServerlessApplicationLocation;
    static readonly PostgresRotationSingleUser: ServerlessApplicationLocation;
    static readonly SqlServerRotationSingleUser: ServerlessApplicationLocation;
    readonly applicationId: string;
    readonly semanticVersion: string;
    constructor(applicationId: string, semanticVersion: string);
}
/**
 * The RDS database engine
 */
export declare enum DatabaseEngine {
    /**
     * MariaDB
     */
    MariaDb = "mariadb",
    /**
     * MySQL
     */
    Mysql = "mysql",
    /**
     * Oracle
     */
    Oracle = "oracle",
    /**
     * PostgreSQL
     */
    Postgres = "postgres",
    /**
     * SQL Server
     */
    SqlServer = "sqlserver"
}
/**
 * Options to add single user rotation to a database instance or cluster.
 */
export interface RotationSingleUserOptions {
    /**
     * Specifies the number of days after the previous rotation before
     * Secrets Manager triggers the next automatic rotation.
     *
     * @default 30 days
     */
    readonly automaticallyAfterDays?: number;
    /**
     * The location of the serverless application for the rotation.
     *
     * @default derived from the target's engine
     */
    readonly serverlessApplicationLocation?: ServerlessApplicationLocation;
}
/**
 * Construction properties for a RotationSingleUser.
 */
export interface RotationSingleUserProps extends RotationSingleUserOptions {
    /**
     * The secret to rotate. It must be a JSON string with the following format:
     * {
     *   'engine': <required: database engine>,
     *   'host': <required: instance host name>,
     *   'username': <required: username>,
     *   'password': <required: password>,
     *   'dbname': <optional: database name>,
     *   'port': <optional: if not specified, default port will be used>
     * }
     *
     * This is typically the case for a secret referenced from an AWS::SecretsManager::SecretTargetAttachment
     * https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-secretsmanager-secrettargetattachment.html
     */
    readonly secret: secretsmanager.ISecret;
    /**
     * The database engine. Either `serverlessApplicationLocation` or `engine` must be specified.
     *
     * @default - No engine specified.
     */
    readonly engine?: DatabaseEngine;
    /**
     * The VPC where the Lambda rotation function will run.
     */
    readonly vpc: ec2.IVpc;
    /**
     * The type of subnets in the VPC where the Lambda rotation function will run.
     *
     * @default - Private subnets.
     */
    readonly vpcSubnets?: ec2.SubnetSelection;
    /**
     * The target database cluster or instance
     */
    readonly target: ec2.IConnectable;
}
/**
 * Single user secret rotation for a database instance or cluster.
 */
export declare class RotationSingleUser extends cdk.Construct {
    constructor(scope: cdk.Construct, id: string, props: RotationSingleUserProps);
}
